Introduction
---------------

tribune is a reporting library for Flask and other Python web frameworks which allows developers
to create Excel report classes with a declarative style, similar to SQLAlchemy ORM.

For now, if you are interested in using it, you will need to see the source code and tests therein
for example usage.

Current Status
---------------

Currently beta quality.
